# -*- coding: utf-8 -*-
import os
import django.conf.global_settings
gettext_noop = lambda s: s

BASE_DIR = os.path.join(os.path.dirname(__file__), '..')
PROJECT_NAME = 'docbow'
ETC_DIR = os.path.join('/etc', PROJECT_NAME)

# boolean settings
__ENVIRONMENT_DEFAULTS = dict(
        # booleans
        DEBUG=False,
        DEBUG_PROPAGATE_EXCEPTIONS=False,
        USE_DEBUG_TOOLBAR=False,
        TEMPLATE_DEBUG=False,
        # paths
        STATIC_ROOT='/var/lib/%s/collectstatic' % PROJECT_NAME,
        STATIC_URL='/static/',
        MEDIA_ROOT='/var/lib/%s/media' % PROJECT_NAME,
        MEDIA_URL='/media/',
        # i18n/l18n
        TIME_ZONE = 'Europe/Paris',
        LANGUAGE_CODE = 'fr',
        SITE_ID = 1,
        USE_I18N=True,
        USE_L10N=True,
        USE_TZ=True,
        # core
        ROOT_URLCONF='docbow_project.urls',
        TEMPLATE_DIRS=('/var/lib/%s/templates' % PROJECT_NAME,),
        STATICFILES_DIRS=('/var/lib/%s/static/' % PROJECT_NAME,),
        GRAPPELLI_ADMIN_TITLE=u"Plate-forme sécurisée d'échange de documents",
        FILE_PER_PAGE=30,
        DO_NOT_SEND_GROUPS=(
                u'Administrateurs des groupes',
                u'Administrateurs des types de document',
                u'Administrateurs des utilisateurs',
                u"Utilisateurs de l'application" ),
        CONTACT_GROUPS=(u'Contact « Administrateur du système »',),
        LOCALE_PATHS=(os.path.join(BASE_DIR, 'docbow_project', 'locale'),),
        DEFAULT_FROM_EMAIL='admin@example.com',
        CONTACT_SUBJECT_PREFIX='Contact depuis docbow: ',
        ALLOWED_HOSTS=['*'],
        LOGIN_REDIRECT_URL='/inbox',
        MESSAGE_STORAGE='django.contrib.messages.storage.fallback.FallbackStorage',
        AUTHENTICATION_BACKENDS=(
                'docbow_project.docbow.auth_backend.DelegationAuthBackend',
                'django.contrib.auth.backends.ModelBackend' ),
        INTERNAL_IPS=('127.0.0.1','82.234.244.169'),
        ADMINS=(),
        SECRET_KEY=None,
        SOUTH_TESTS_MIGRATE=True,
        OVH_SMS_ACCOUNT='sms-db26857-1',
        OVH_SMS_LOGIN='pfwb',
        OVH_SMS_PASSWORD='',
        OVH_SMS_FROM='Dauvergne',
        DOCBOW_SMS_CARRIER_CLASS='docbow_project.docbow.sms_carrier_ovh.OVHSMSCarrier',
        DOCBOW_ORGANIZATION_SHORT='PFWB',
        DOCBOW_ORGANIZATION=u'Parlement de la Fédération Wallonie-Bruxelles',
        DOCBOW_NOTIFIERS=(
                'docbow_project.docbow.notification.MailNotifier',
                'docbow_project.docbow.notification.SMSNotifier',
        ),
        DOCBOW_PFWB_GED_DIRECTORY='/var/lib/docbow/ged/',
        DOCBOW_PFWB_SENDMAIL_DEFAULT_TYPE_ID=None,
        DOCBOW_PFWB_SENDMAIL_DEFAULT_TYPE_NAME=u'Divers',
        DOCBOW_PFWB_SENDMAIL_TABELLIO_EXPEDITION_EMAIL='commande.documents@pfwb.be',
        DOCBOW_PFWB_SENDMAIL_TABELLIO_EXPEDITION_USER_ID=None,
        DOCBOW_PFWB_SENDMAIL_ATTACHED_FILE_EMAIL='dontknow@pfwb.be',
        DOCBOW_PFWB_SENDMAIL_ATTACHED_FILE_USER_ID=None,
        TEMPLATE_CONTEXT_PROCESSORS=django.conf.global_settings.TEMPLATE_CONTEXT_PROCESSORS +
                    ('django.core.context_processors.request',
                     'docbow_project.docbow.context_processors.logout_url_processor'),
        DATE_INPUT_FORMATS=('%d/%m/%Y', '%Y-%m-%d'),
        CRISPY_TEMPLATE_PACK='uni_form',
        DOCBOW_TIMESTAMP_PROVIDER='certum',
        RAVEN_CONFIG_DSN='',
        DOCBOW_MAX_FILE_SIZE=10*1024*1024,
        CUSTOMIZATION='pfwb',
        DOCBOW_PRIVATE_DOCUMENTS=False,
        DOCBOW_BASE_URL='http://localhost:8000',
        PLATFORM='prod',
        DOCBOW_EDIT_EMAIL=False,
        EMAIL_HOST='localhost',
        SECURE_PROXY_SSL_HEADER = (),
        SESSION_COOKIE_AGE=7200,
)

for key, default in __ENVIRONMENT_DEFAULTS.iteritems():
    try:
        value = os.environ[key]
        if default is True or default is False:
            if value.isdigit():
                value = bool(int(value))
            else:
                value = value.lower() in ('yes', 'true', 'y')
        elif isinstance(default, (tuple, list)):
            value = [ x.strip() for x in value.split(':')]
            if len(default) or key in ('ADMINS',):
                if key in ('ADMINS',) or isinstance(default[0], (tuple, list)):
                    value = [ x.split(';') for x in value ]
                elif isinstance(default[0], unicode):
                    value = [ unicode(x, 'utf8') for x in value ]
        elif isinstance(default, unicode):
            value = unicode(value, 'utf8')
        elif isinstance(default, int):
            value = int(value)
    except KeyError:
        value = default
    globals()[key] = value

MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': os.environ.get('DATABASE_ENGINE', 'django.db.backends.sqlite3'),
        'NAME': os.environ.get('DATABASE_NAME', os.path.join(BASE_DIR, PROJECT_NAME + '.db')),
    }
}

# Hey Entr'ouvert is in France !!

LANGUAGES = (
    ('fr', gettext_noop('French')),
)

if DEBUG:
    TEMPLATE_LOADERS = (
        'django.template.loaders.filesystem.Loader',
        'django.template.loaders.app_directories.Loader',
    )
else:
    TEMPLATE_LOADERS = (
        ('django.template.loaders.cached.Loader', (
            'django.template.loaders.filesystem.Loader',
            'django.template.loaders.app_directories.Loader',)),
    )

ATOMIC_REQUESTS = True

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'docbow_project.docbow.middleware.KeepUserAroundMiddleware',
    'django_journal.middleware.JournalMiddleware',
    'watson.middleware.SearchContextMiddleware',
)


INSTALLED_APPS = (
    'django.contrib.contenttypes',
    'django.contrib.auth',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.humanize',
    'watson',
    'autocomplete_light',
    'grappelli',
    'django.contrib.admin',
    'django_tables2',
    'django_journal',
    'crispy_forms',
    'south',
    'entrouvert.djommon.humantime',
    'docbow_project.docbow',
)

STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
)

import logging.handlers

LOGGING = {
    'version': 1,
    'disable_existing_loggers': True,
    'formatters': {
        'syslog': {
            'format': PROJECT_NAME + '(pid=%(process)d) %(levelname)s %(name)s: %(message)s',
        },
        'syslog_debug': {
            'format': PROJECT_NAME + '(pid=%(process)d) %(levelname)s %(asctime)s t_%(thread)s %(name)s: %(message)s',
        },
    },
    'handlers': {
        'syslog': {
            'level': 'DEBUG',
            'class': 'entrouvert.logging.handlers.SysLogHandler',
            'formatter': 'syslog_debug' if DEBUG else 'syslog',
            'facility': logging.handlers.SysLogHandler.LOG_LOCAL0,
            'address': '/dev/log',
            'max_length': 999,
            'filters': [],
        },
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler',
            'filters': [],
            'include_html': True,
        },
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'syslog_debug',
            'level': 'DEBUG',
        },
    },
    'loggers': {
        'django.db': {
            'handlers': [ ],
            'level': 'INFO',
            'propagate': True,
        },
        'django.request': {
            'handlers': [ ],
            'propagate': True,
        },
        '': {
            'handlers': [ 'syslog' ],
            'level': 'INFO',
        },
    },
}
# Remove after Django 1.7
SERIALIZATION_MODULES = { 
    'json': 'docbow_project.serializers',
}


try:
    from local_settings import *
except ImportError, e:
    if 'local_settings' not in e.args[0]:
        raise

if DEBUG:
    LOGGING['loggers']['']['level'] = 'DEBUG'
    LOGGING['loggers']['']['handlers'].append('console')

INSTALLED_APPS += ('docbow_project.' + CUSTOMIZATION,)
TEMPLATE_DIRS += (os.path.join(BASE_DIR, 'docbow_project', CUSTOMIZATION, 'templates'),)
TEMPLATE_DIRS += (os.path.join(BASE_DIR, 'docbow_project', 'docbow', 'templates'),)
STATICFILES_DIRS += (os.path.join(BASE_DIR, 'docbow_project', CUSTOMIZATION, 'static'),)
STATICFILES_DIRS += (os.path.join(BASE_DIR, 'docbow_project', 'docbow', 'static'),)


if RAVEN_CONFIG_DSN:
    LOGGING['handlers']['sentry'] = {
            'level': 'ERROR',
            'class': 'raven.handlers.logging.SentryHandler',
            'dsn': RAVEN_CONFIG_DSN,
        }
    for logger in LOGGING['loggers'].values():
        if 'syslog' in logger['handlers']:
            logger['handlers'].append('sentry')
else:
    for logger in LOGGING['loggers'].values():
        if 'syslog' in logger['handlers']:
            logger['handlers'].append('mail_admins')

if DEBUG and 'SECRET_KEY' not in globals():
    SECRET_KEY = 'coin'

if USE_DEBUG_TOOLBAR:
    try:
        import debug_toolbar
        INSTALLED_APPS += ('debug_toolbar',)
    except ImportError:
        print "Debug toolbar missing, not loaded"

# syntax checks
for admin in ADMINS:
    assert len(admin) == 2, 'ADMINS setting must be a colon separated list of name and emails separated by a semi-colon: %s' % ADMINS
    assert '@' in admin[1], 'ADMINS setting pairs second value must be emails: %s' % ADMINS

STATSD_CLIENT = os.environ.get('STATSD_CLIENT', 'django_statsd.clients.null')

if STATSD_CLIENT != 'django_statsd.clients.null':
    MIDDLEWARE_CLASSES = (
        'django_statsd.middleware.GraphiteRequestTimingMiddleware',
        'django_statsd.middleware.GraphiteMiddleware',
    ) + MIDDLEWARE_CLASSES
    INSTALLED_APPS += ( 'django_statsd',)

ETC_SETTINGS_PY = os.path.join(ETC_DIR, 'settings.py')

if os.path.exists(ETC_SETTINGS_PY):
    execfile(ETC_SETTINGS_PY, globals())
