import watson
import autocomplete_light
from autocomplete_light.autocomplete.base import AutocompleteBase

from . import sql, models, views

class WatsonAutocompleteBase(object):
    limit_choices = 10
    outbox = False

    def choices_for_values(self):
        return ()


    def choices_for_request(self):
        q = self.request.GET.get('q', '')

        documents = sql.get_documents(models.Document.objects.all(),
            views.get_related_users(self.request), self.request.user, self.outbox,)
        search = watson.search(q, models=(documents,))
        choices = []
        for match in search:
            match_words = [word for word in match.description.split() if word.lower().startswith(q.lower())]
            for word in match_words:
                if word in choices:
                    continue
                choices.append(word)
                if len(choices) == self.limit_choices:
                    break
            if len(choices) == self.limit_choices:
                break
        return choices

class WatsonAutocomplete(WatsonAutocompleteBase, AutocompleteBase):
    autocomplete_js_attributes = {
        'minimum_characters': 2,
        'xhrWait': 400,
    }


class WatsonAutocompleteOutbox(WatsonAutocomplete):
    outbox = True


autocomplete_light.register(WatsonAutocomplete)
autocomplete_light.register(WatsonAutocompleteOutbox)
